src/eric7/Debugger/StartDialog.py

branch
eric7-maintenance
changeset 9305
3b7ef53c34c7
parent 9264
18a7312cfdb3
parent 9291
7b271bcd12d0
child 9442
906485dcd210
--- a/src/eric7/Debugger/StartDialog.py	Mon Jul 25 16:58:55 2022 +0200
+++ b/src/eric7/Debugger/StartDialog.py	Fri Sep 02 14:07:46 2022 +0200
@@ -35,6 +35,7 @@
         wdList,
         envList,
         exceptions,
+        unhandledExceptions,
         parent=None,
         dialogType=0,
         modfuncList=None,
@@ -64,6 +65,8 @@
         @type list of str
         @param exceptions exception reporting flag
         @type bool
+        @param unhandledExceptions flag indicating to always report unhandled exceptions
+        @type bool
         @param parent parent widget of this dialog
         @type QWidget
         @param dialogType type of the start dialog
@@ -174,6 +177,7 @@
         self.ui.environmentCombo.clear()
         self.ui.environmentCombo.addItems(envList)
         self.ui.exceptionCheckBox.setChecked(exceptions)
+        self.ui.unhandledExceptionCheckBox.setChecked(unhandledExceptions)
         self.ui.clearShellCheckBox.setChecked(autoClearShell)
         self.ui.consoleCheckBox.setEnabled(
             Preferences.getDebugger("ConsoleDbgCommand") != ""
@@ -229,9 +233,9 @@
         Public method to retrieve the data entered into this dialog.
 
         @return a tuple of virtual environment, script name, argv, workdir,
-            environment, exceptions flag, clear interpreter flag and run in
-            console flag
-        @rtype tuple of (str, str, str, str, str, bool, bool, bool)
+            environment, exceptions flag, unhandled exceptions flag, clear interpreter
+            flag and run in console flag
+        @rtype tuple of (str, str, str, str, str, bool, bool, bool, bool)
         """
         cmdLine = self.ui.cmdlineCombo.currentText()
         workdir = self.ui.workdirPicker.currentText(toNative=False)
@@ -250,6 +254,7 @@
             workdir,
             environment,
             self.ui.exceptionCheckBox.isChecked(),
+            self.ui.unhandledExceptionCheckBox.isChecked(),
             self.ui.clearShellCheckBox.isChecked(),
             self.ui.consoleCheckBox.isChecked(),
         )

eric ide

mercurial